%global llvm_version 15
%global soversion 103

%bcond_with bootstrap

%undefine _hardened_build
%undefine _package_note_file

Name:           ldc
Version:        1.33.0
Release:    1%{?dist}
Summary:        LLVM D Compiler

License:        BSD
URL:            https://github.com/ldc-developers/ldc
Source0:        https://github.com/ldc-developers/ldc/releases/download/v%{version_no_tilde}/%{name}-%{version_no_tilde}-src.tar.gz
Source3:        macros.%{name}

Patch0:         ldc-include-path.patch
Patch1:         ldc-no-default-rpath.patch

ExclusiveArch:  %{ldc_arches} ppc64le

BuildRequires:  bash-completion
BuildRequires:  cmake
BuildRequires:  gc
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  ldc
BuildRequires:  libconfig-devel
BuildRequires:  libcurl-devel
BuildRequires:  libedit-devel
BuildRequires:  llvm%{?llvm_version}-devel
BuildRequires:  llvm%{?llvm_version}-static
BuildRequires:  make
BuildRequires:  zlib-devel

Requires:       %{name}-libs = %{version}-%{release}
Requires:       gcc


%description
LDC is a portable compiler for the D programming language with modern
optimization and code generation capabilities.

It uses the official DMD compiler frontend to support the latest version
of D, and relies on the LLVM Core libraries for code generation.

%package        libs
Summary:        LLVM D Compiler libraries
License:        Boost

%description    libs
LDC is a portable compiler for the D programming language with modern
optimization and code generation capabilities.

This package contains the Phobos D standard library and the D runtime library.

%prep
%autosetup -n %{name}-%{version_no_tilde}-src -p1

%build
%define _lto_cflags %{nil}

%global optflags %{optflags} -fno-strict-aliasing

%if %{with bootstrap}
tar xf %{SOURCE0}
mkdir build-bootstrap
pushd build-bootstrap
cmake -DLLVM_CONFIG:PATH=llvm-config%{?llvm_version:-%{llvm_version}} \
      ../%{name}-%{version_no_tilde}-src
make %{?_smp_mflags}
popd
%endif

%cmake -DMULTILIB:BOOL=OFF \
       -DINCLUDE_INSTALL_DIR:PATH=%{_prefix}/lib/ldc/%{_target_platform}/include/d \
       -DBASH_COMPLETION_COMPLETIONSDIR:PATH=%{_datadir}/bash-completion/completions \
       -DLLVM_CONFIG:PATH=llvm-config%{?llvm_version:-%{llvm_version}} \
%if %{with bootstrap}
       -DD_COMPILER:PATH=`pwd`/build-bootstrap/bin/ldmd2 \
%endif
       %{nil}

%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}/%{_rpmconfigdir}/macros.d/
install --mode=0644 %{SOURCE3} %{buildroot}%{_rpmconfigdir}/macros.d/macros.ldc

%files
%license LICENSE
%doc README.md
%config(noreplace) %{_sysconfdir}/ldc2.conf
%{_bindir}/ldc2
%{_bindir}/ldmd2
%{_bindir}/ldc-build-plugin
%{_bindir}/ldc-build-runtime
%{_bindir}/ldc-profdata
%{_bindir}/ldc-prune-cache
%{_bindir}/timetrace2txt
%{_rpmconfigdir}/macros.d/macros.ldc
%dir %{_prefix}/lib/ldc
%dir %{_prefix}/lib/ldc/%{_target_platform}
%dir %{_prefix}/lib/ldc/%{_target_platform}/include
%{_prefix}/lib/ldc/%{_target_platform}/include/d/
%{_libdir}/ldc_rt.dso.o
%{_libdir}/libdruntime-ldc-debug-shared.so
%{_libdir}/libdruntime-ldc-shared.so
%{_libdir}/libphobos2-ldc-debug-shared.so
%{_libdir}/libphobos2-ldc-shared.so
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/ldc2

%files libs
%license runtime/phobos/LICENSE_1_0.txt
%{_libdir}/libdruntime-ldc-debug-shared.so.%{soversion}*
%{_libdir}/libdruntime-ldc-shared.so.%{soversion}*
%{_libdir}/libphobos2-ldc-debug-shared.so.%{soversion}*
%{_libdir}/libphobos2-ldc-shared.so.%{soversion}*

%changelog
* Tue Aug 06 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.33.0-1
- initial build
